<?php
/**
 * @file
 *  Provides Shortcodes for Audio posts..
 */

namespace Drupal\shortcode_audio\Plugin\Shortcode;

use Drupal\Core\Language\Language;
use Drupal\shortcode\Plugin\ShortcodeBase;
use Drupal\Component\Utility\UrlHelper;
use Drupal\Component\Utility\Html;

/**
 * Provides a shortcode for Audio posts.
 *
 * @Shortcode(
 *   id = "audio",
 *   title = @Translation("Audio Shortcode"),
 *   description = @Translation("Embeds a audio post using shortcodes")
 * )
 */
class AudioShortcode extends ShortcodeBase {

  /**
   * {@inheritdoc}
   */
  public function process($attributes, $text, $langcode = Language::LANGCODE_NOT_SPECIFIED) {
    $attributes = $this->getAttributes(array(
      'class' => 'soundcloud',
    ),
      $attributes
    );

    $text = Html::decodeEntities($text);
    $url = UrlHelper::parse($text);
    $url = strip_tags($url['path']);
    $class = $attributes['class'];

//    $output = [
//      '#theme' => 'shortcode_audio',
//      '#url' => $url,
//      '#class' => $class,
//    ];

    //return $this->render($output);
    return '<div class="shortcode-audio ' . $class . '" data="' . $url . '"></div>';
  }

  /**
   * {@inheritdoc}
   */
  public function tips($long = FALSE) {
    $output = array();
    $output[] = '<strong>' . t('[audio]https://soundcloud.com/forss/flickermood[/audio]') . '</strong> ';
    if ($long) {
      $output[] = t('Outputs HTML which will get the URL to use to display an embedded soundcloud post');
    }
    else {
      $output[] = t('Outputs HTML to display an embedded soundcloud post');
    }

    return implode(' ', $output);
  }
}